#
# spec file for package ckb-next
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ckb-next
Version:        0.4.2
Release:        lp152.1.5
Summary:        RGB driver for Corsair keyboard and mice
License:        GPL-2.0-only AND BSD-3-Clause
Group:          Hardware/Other
URL:            https://github.com/ckb-next/ckb-next
Source:         https://github.com/ckb-next/ckb-next/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE ckb-next-use-run.patch
Patch1:         ckb-next-use-run.patch
# PATCH-FIX-OPENSUSE ckb-next-systemd.patch
Patch2:         ckb-next-systemd.patch
# PATCH-FIX-OPENSUSE ckb-next-no-cmake-modules.patch
Patch3:         ckb-next-no-cmake-modules.patch
# PATCH-FIX-UPSTREAM ckb-next-udev.patch
Patch4:         ckb-next-udev.patch
# PATCH-FIX-UPSTREAM 422.patch boo#1135528
Patch5:         422.patch
BuildRequires:  ImageMagick
BuildRequires:  cmake
BuildRequires:  hicolor-icon-theme
%if 0%{?suse_version} >= 1500
BuildRequires:  quazip-qt5-devel
%endif
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(zlib)
Obsoletes:      ckb < %{version}
Provides:       ckb = %{version}
Requires:       bash
%{systemd_requires}

%description
ckb is a driver for Corsair keyboards and mice. It brings the
features of their proprietary CUE software to the Linux operating
system. This project supports much of the same functionality,
including full RGB animations.

%prep
%autosetup -p1

%build
%cmake \
       -DDISABLE_UPDATER=1 \
       -DCMAKE_INSTALL_LIBEXECDIR=%{_libexecdir} \
       -DUDEV_RULE_DIRECTORY=%{_udevrulesdir}
%cmake_build

%install
%cmake_install
for s in 16 22 32 48 64 96 128 192 256; do
   mkdir -pv %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps
   convert -strip -resize ${s}x${s} %{buildroot}%{_datadir}/icons/hicolor/512x512/apps/ckb-next.png \
    %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/%{name}.png
done
mkdir %{buildroot}%{_sbindir}
ln -sf service %{buildroot}%{_sbindir}/rc%{name}-daemon
%suse_update_desktop_file -r %{name} Settings HardwareSettings

%pre
%service_add_pre %{name}-daemon.service

%post
%service_add_post %{name}-daemon.service

%preun
%service_del_preun %{name}-daemon.service

%postun
%service_del_postun %{name}-daemon.service

%files
%license LICENSE
%doc CHANGELOG.md FIRMWARE README.md
%{_bindir}/%{name}
%{_bindir}/%{name}-dev-detect
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_sbindir}/rc%{name}-daemon
%{_libexecdir}/%{name}-daemon
%{_libexecdir}/%{name}-animations
%{_udevrulesdir}/99-%{name}-daemon.rules
%{_unitdir}/%{name}-daemon.service

%changelog
* Wed Nov 20 2019 Simon Lees <sflees@suse.de>
- %%make_jobs is depricated replaced by %%cmake_build
- Use %%autosetup to simplify maintenance
* Tue Oct  8 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.2
  Support for new devices:
  * Harpoon RGB Pro
  * Ironclaw RGB
  Important bugfixes:
  * GUI no longer crashes if an animation has no keys set
* Tue Aug 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.1
  Important bugfixes:
  * Specified keyboard layout is no longer being reverted on
    restart
  * Pipe animation no longer quits if it can't read data
  * Media keys work again on the legacy K65
  * Daemon no longer crashes on quit on macOS
  * Devices are now re-activated after resume on Linux
  * Gradient animation no longer flickers with dithering enabled
  * HiDPI has been disabled by default due to screen resolution
    misdetection
  * Max DPI is now per-device
  * Extra words are now filtered from the device name
  * gpg2 is preferred over gpg for signature verification
  New features:
  * An uninstall button has been added for macOS users that
    allows complete uninstallation, including older versions
  * Life animation has a new transparent preset
  * Confirmation dialog boxes have been added when deleting
    profiles, modes, and animations
  * Animation preview now gets temporarily disabled while
    ckb-next is out of focus
  * Support for multiple animation paths has been added
  * Pollrate can now be changed through the GUI
  Notes for packagers:
  * Udev rules are now installed by default in /lib/udev/rules.d.
  * Udev rule installation path can be changed with
    UDEV_RULE_DIRECTORY in cmake
  * Init systems can manually be force-enabled with
    FORCE_INIT_SYSTEM in cmake
- Refreshed ckb-next-use-run.patch and ckb-next-systemd.patch
* Wed May 29 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add 422.patch to fix animations dir (boo#1135528)
* Sat Mar  9 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.0
  Support for new devices:
  * K70 RGB MK.2 LP
  * M65 RGB Elite
  * M95 Legacy
  Important bugfixes:
  * ST100 now works on macOS properly
  * Strafe RGB MK.2 logo is mapped to the right LEDs, and media
    buttons are positioned correctly
  * A buffer overflow causing the daemon to crash or hang has
    been fixed
  * quickinstall can now run correctly with multibyte characters
    in the path
  * Rename now works correctly in the Profile Manager context
    menu
  * Animations with no presets no longer get loaded to prevent
    crashes
  * K70 Lux is now marked correctly as monochrome
  * ckb-next can be built again with Qt 5.2
  * Save to hardware now gets disabled in the context menu for
    unsupported devices
  * Settings backend has been changed to ini for macOS,
    preventing silent configuration data corruption
  * The K55, the ST100 and the Polaris now have working default
    profiles
  * A few cases that may cause the GUI to crash have been found
    and fixed
  * Blank animation names are no longer allowed
  New features:
  * GUI has gained a monochrome tray icon option
    (QSystemTrayIcon only)
  * Device brightness can be controlled by scrolling on the tray
    icon on Linux systems that support it (AppIndicator or KDE)
  * Profiles and modes can now be changed with the --profile and
  - -mode arguments passed to the GUI binary
  * New Conway's Game of Life animation
  * New 'snake' animation
  * New 'pipe' animation, allowing the user to send rgb data
    from external applications
  * Music Visualizer (mviz) is now supported on macOS, and has
    been reworked to function correctly
  * A --version argument has been added to the daemon
  Notes:
  * On Linux, the udev rule has been renamed and moved
  * On Linux, for builds with libappindicator, it can be force
    enabled/disabled by setting the CKB_NEXT_USE_APPINDICATOR
    environment variable
  * On Linux, libappindicator support is also enabled if the Qt
    platform theme is gtk2 (Useful for Unity on Ubuntu 19.04)
  * The restart command has been removed from the daemon
  * Threads are now named for easier debugging
  * Signal handler has been rewritten
  * A few unneeded packets are no longer being sent to M65 mice
  * Only Red channel data is being sent to monochrome devices
- Refreshed ckb-next-systemd.patch and ckb-next-udev.patch
* Thu Jan 10 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description.
* Tue Jan  8 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.3.2
  Important news:
  * This version fixes a major bug for the Scimitar Pro, causing
    the daemon to not properly interface with the mouse. This
    could require manually reflashing the mouse firmware if a
    firmware update was performed with 0.3.1 or earlier.
  * An updater has been created to more quickly push bugfixes to
    users, especially for those on macOS.
  * There is a new Space Invaders-like minigame that can be
    played as an animation, thanks to @mvladimirovich.
  Support for new devices:
  * Strafe RGB MK.2; by accidental omission from the previous
    release.
  * K66
  Important bugfixes:
  * The Scimitar Pro now defaults to v2.xx endpoints
  * The DPI LED on mice now changes in sniper mode
  * The GUI will warn if uinput cannot be loaded on Linux
  * The "Save to Hardware" button on the Scimitar and Glaive has
    been greyed out due to a current lack of support
  * Thanks to the efforts of @Kedstar99, the codebase compiles
    with much fewer warnings
  * Binding commands to wheels will now repeat properly
  * QuaZip is no longer required for daemon-only builds
  * KissFFT is now built as a static library
  * Symbolic links are now created in /dev/input/by-id for evdev
    users
  * Fixed a regression for devices using the legacy protocol
  Note for packagers:
  * If ckb-next is updated through a package management system,
    `-DDISABLE_UPDATER=1` should be passed to CMake
  version 0.3.1
  Support for new devices:
  * K70 RGB MK.2
  * K70 RGB MK.2 SE
  New major features:
  * The GUI now has a generate ckb-next-dev-detect report button
  Important bugfixes:
  * Rapidfire keyboards have a workaround on shutdown
  * Bugfix for independent X/Y DPI
  * The new Strafe NRGB has firmware updates now
  * The GUI pops up a warning when trying to bind the Windows
    key with Winlock enabled
  * The GUI now has a DPI indicator
  * The K68 NRGB winlock light now lights up
  * The GUI handles SIGINT/SIGTERM cleanly, avoiding stalled
    devices
  * Strafe sidelights now save state on GUI start
  * Original Strafe NRGB's sidelights now toggle correctly
  * ckb-next-dev-detect is now installed to the system and added
    to PATH
  version 0.3.0
  Support for new devices:
  * K55 RGB
  * K68 RGB
  * K90 Legacy
  * Katar RGB
  * Polaris RGB
  * ST100 RGB
  New major features:
  * Use URB Interrupts to read data from devices
  * Profile Import/Export
  * Keyboard Layout autodetection
  * CMake build system
  * Relocation of binaries
  * No single global layout for all devices in the GUI
  Important bugfixes:
  * Deadlock on daemon exit
  * Support for K95 Platinum profile switch key
  * Keymap corruption on the GUI
  * Pulseaudio GUI deadlock
  * Use udev to detect the appropriate endpoint max packet size
  * Ignore devices in BIOS mode
  * Disable save to hardware for unsupported devices
  * Keymap patches for K68
  * Workaround for linux kernel out-of-bounds write
  * Memory leaks on firmware update
  version 0.2.9
  Important changes:
  * Significantly lower CPU usage on idle
  * Add support for K95 Platinum
  * Add support for K68
  * Add support for (new) Strafe non-RGB
  * Add support for Glaive
  * Add support for Harpoon
  * Add support for Corsair firmware v3
  * Add support for pt\_br layout
  * Add support for Japanese layout
  * Add macro delays to the GUI
  * New FIRMWARE file structure
  * GUI warning when daemon is not running
  * udev rule to remove joystick tag
  * Dynamic keymap patching
  * Require Qt >=5.2
  * Numerous small fixes and improvements
  version 0.2.8
  * `ckb` is now `ckb-next`, __but the binaries will be renamed
    in `v0.2.9`__
  * Numerous PRs from `ckb` merged
    [\#4](https://github.com/mattanger/ckb-next/issues/4)
  * SIGSEGV when deleting copied profile is fixed
    [\#38](https://github.com/mattanger/ckb-next/issues/38)
  * `make debug` target on Linux is fixed
    [\#79](https://github.com/mattanger/ckb-next/issues/79)
  * Heat map animation issues fixed
    [\#30](https://github.com/mattanger/ckb-next/issues/30)
  * Compilation of the music visualizer fixed
    [\#21](https://github.com/mattanger/ckb-next/issues/21)
  * Hardware profile loading error on firmware 2.05 fixed
    [\#24](https://github.com/mattanger/ckb-next/pull/24)
  * Project's own firmware table created, signed and populated
    with new devices
    [\#60](https://github.com/mattanger/ckb-next/pull/60)
  * Arch Linux and Fedora/CentOS packages added
    [\#80](https://github.com/mattanger/ckb-next/pull/80)
    [\#5](https://github.com/mattanger/ckb-next/issues/5)
    [\#41](https://github.com/mattanger/ckb-next/pull/41)
- Dropped ckb-external-quazip.patch (no longer necessary)
- Refreshed ckb-use-var-run.patch as ckb-next-use-run.patch
- Added ckb-next-systemd.patch, ckb-next-no-cmake-modules.patch
  and ckb-next-udev.patch
* Thu Aug 25 2016 aloisio@gmx.com
- Update to version 0.2.6
- Use external quazip only when available
- Replaced ckb-fix-desktop-file.patch with %%suse_update_desktop_file
- Replaced ckb-daemon-path.patch and ckb-animations-path.patch
  with macros for consistency.
* Sun Apr 17 2016 herbert@graeber-clan.de
- Add hicoler folder, too
* Sun Apr 17 2016 herbert@graeber-clan.de
- Fix icon folder
* Fri Apr 15 2016 herbert@graeber-clan.de
- Initial package
  * Use /var/run instead of /dev/input for communication with the
    daemon.
  * move the daemon and the animations into the libexec folder
